Welcome to the Plaso documentation
=======================================

Plaso (Plaso Langar Að Safna Öllu), or *super timeline all the things*, is a
Python-based engine used by several tools for automatic creation of timelines.
Plaso default behavior is to create super timelines but it also supports
creating more `targeted timelines <http://blog.kiddaland.net/2013/02/targeted-timelines-part-i.html>`__.

These timelines support digital forensic investigators/analysts, to correlate
the large amount of information found in logs and other files found on an
average computer.

The source code is available from the `project page <https://github.com/log2timeline/plaso>`__.

.. toctree::
   :maxdepth: 2

   sources/user/index

.. toctree::
   :maxdepth: 2

   sources/developer/index

.. toctree::
   :maxdepth: 2

   Troubleshooting <sources/Troubleshooting>

.. toctree::
   :maxdepth: 2

   Supported formats <sources/Supported-formats>

.. toctree::
   :maxdepth: 2

   API documentation <sources/api/plaso>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`

